checkStrata: A function to check if the composition and fallback strata...

View source: R/util.R

checkStrataR Documentation

A function to check if the composition and fallback strata are compatible. Each composition stratum must have one and only one fallback stratum

Description

A function to check if the composition and fallback strata are compatible. Each composition stratum must have one and only one fallback stratum

Usage

checkStrata(stratAssign_comp, stratAssign_fallback, quiet = FALSE)

Arguments

stratAssign_comp

the strata assignment tibble for composition estimates

stratAssign_fallback

the strata assignment tibble for fallback/reascension estimates

quiet

when FALSE, it prints a message confirming that strata are compatible


delomast/escapeLGD documentation built on June 9, 2025, 10:52 p.m.