| checkStrata | R Documentation |
A function to check if the composition and fallback strata are compatible. Each composition stratum must have one and only one fallback stratum
checkStrata(stratAssign_comp, stratAssign_fallback, quiet = FALSE)
stratAssign_comp |
the strata assignment tibble for composition estimates |
stratAssign_fallback |
the strata assignment tibble for fallback/reascension estimates |
quiet |
when FALSE, it prints a message confirming that strata are compatible |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.